@@ -47,12 +47,11 @@ LY_DEFINE (ly_run_translator, "ly:run-translator",
   if (!music
       || !music->get_length ().to_bool ())
     {
-      warning (_ ("Need music in a score"));
+      warning (_ ("no music found in score"));
       return SCM_BOOL_F;
     }
 
-  SCM_ASSERT_TYPE (music, mus, SCM_ARG1,
-		   __FUNCTION__, "Music");
+  SCM_ASSERT_TYPE (music, mus, SCM_ARG1, __FUNCTION__, "Music");
   SCM_ASSERT_TYPE (odef, output_def, SCM_ARG2, __FUNCTION__,
 		   "Output definition");
 
@@ -65,7 +64,7 @@ LY_DEFINE (ly_run_translator, "ly:run-translator",
       return SCM_BOOL_F;
     }
 
-  progress_indication (_ ("Interpreting music... "));
+  message (_ ("Interpreting music... "));
 
   SCM protected_iter = Music_iterator::get_static_get_iterator (music);
   Music_iterator *iter = unsmob_iterator (protected_iter);
@@ -75,7 +74,7 @@ LY_DEFINE (ly_run_translator, "ly:run-translator",
 
   if (!iter->ok ())
     {
-      warning (_ ("Need music in a score"));
+      warning (_ ("no music found in score"));
       /* todo: should throw exception. */
       return SCM_BOOL_F;
     }
@@ -86,7 +85,7 @@ LY_DEFINE (ly_run_translator, "ly:run-translator",
   trans->finish ();
 
   if (be_verbose_global)
-    progress_indication (_f ("elapsed time: %.2f seconds", timer.read ()));
+    message (_f ("elapsed time: %.2f seconds", timer.read ()));
 
   return scm_gc_unprotect_object (trans->self_scm ());
 }
