@@ -1,6 +1,6 @@
 /*
   Implement storage and manipulation of grob properties.
- */
+*/
 
 #include <cstring>
 #include <math.h>
@@ -16,7 +16,6 @@
 #include "misc.hh"
 #include "item.hh"
 
-
 SCM
 Grob::get_property_alist_chain (SCM def) const
 {
@@ -26,21 +25,18 @@ Grob::get_property_alist_chain (SCM def) const
 		     SCM_UNDEFINED);
 }
 
-
-
 /*
   This special add_thing routine is slightly more efficient than
 
-    set_prop (name, cons (thing, get_prop (name)))
+  set_prop (name, cons (thing, get_prop (name)))
 
   since it can reuse the handle returned by scm_assq ().
 */
 void
-Grob::add_to_list_property (SCM sym, SCM thing) 
+Grob::add_to_list_property (SCM sym, SCM thing)
 {
   SCM handle
-    = scm_sloppy_assq (sym, mutable_property_alist_)
-    ;
+    = scm_sloppy_assq (sym, mutable_property_alist_);
 
   if (handle != SCM_BOOL_F)
     {
@@ -57,11 +53,10 @@ Grob::add_to_list_property (SCM sym, SCM thing)
       SCM val = scm_cons (thing, tail);
 
       mutable_property_alist_ = scm_cons (scm_cons (sym, val),
-					 mutable_property_alist_);
+					  mutable_property_alist_);
     }
 }
 
-
 extern void check_interfaces_for_property (Grob const *me, SCM sym);
 
 void
@@ -81,7 +76,6 @@ Grob::internal_set_property (SCM s, SCM v)
   mutable_property_alist_ = scm_assq_set_x (mutable_property_alist_, s, v);
 }
 
-
 SCM
 Grob::internal_get_property (SCM sym) const
 {
@@ -90,7 +84,7 @@ Grob::internal_get_property (SCM sym) const
     return scm_cdr (s);
 
   s = scm_sloppy_assq (sym, immutable_property_alist_);
-  
+
   if (do_internal_type_checking_global && scm_is_pair (s))
     {
       if (!type_check_assignment (sym, scm_cdr (s),
@@ -100,7 +94,7 @@ Grob::internal_get_property (SCM sym) const
       check_interfaces_for_property (this, sym);
     }
 
-  return (s == SCM_BOOL_F) ? SCM_EOL : scm_cdr (s); 
+  return (s == SCM_BOOL_F) ? SCM_EOL : scm_cdr (s);
 }
 
 void
@@ -110,7 +104,6 @@ Grob::substitute_mutable_properties (SCM crit, SCM orig)
   mutable_property_alist_ = substitute_mutable_property_alist (orig);
 }
 
-
 bool
 Grob::is_live () const
 {
