@@ -31,6 +31,7 @@ Hyphen_spanner::print (SCM smob)
 
   Interval span_points;
   Direction d = LEFT;
+  Drul_array<bool> broken;
   do
     {
       Interval iv = bounds[d]->extent (common, X_AXIS);
@@ -47,18 +48,27 @@ Hyphen_spanner::print (SCM smob)
 
   // interval?
 
-  Real dp = robust_scm2double (me->get_property ("dash-period"), 1.0);
-  Real dl = robust_scm2double (me->get_property ("length"), .5);
+  Real dash_period = robust_scm2double (me->get_property ("dash-period"), 1.0);
+  Real dash_length = robust_scm2double (me->get_property ("length"), .5);
+  Real padding = robust_scm2double (me->get_property ("padding"), 0.1);
 
-  if (dp < dl)
-    dp = 1.5 * dl;
+  if (dash_period < dash_length)
+    dash_period = 1.5 * dash_length;
 
   Real l = span_points.length ();
-  int n = int (ceil (l / dp - 0.5));
+
+  int n = int (ceil (l / dash_period - 0.5));
   if (n <= 0)
     n = 1;
 
-  Real space_left = l - dl - (n - 1)* dp;
+  if (l < dash_length + 2 * padding
+      && !bounds[RIGHT]->break_status_dir ())
+    {
+      Real minimum_length = robust_scm2double (me->get_property ("minimum-length"), .3);
+      dash_length = (l - 2 * padding) >? minimum_length;
+    }
+
+  Real space_left = l - dash_length - (n - 1) * dash_period;
 
   /*
     If there is not enough space, the hyphen should disappear, but not
@@ -70,14 +80,14 @@ Hyphen_spanner::print (SCM smob)
 
   space_left = space_left >? 0.0;
 
-  Box b (Interval (0, dl), Interval (h, h + th));
+  Box b (Interval (0, dash_length), Interval (h, h + th));
   Stencil dash_mol (Lookup::round_filled_box (b, 0.8 * lt));
 
   Stencil total;
   for (int i = 0; i < n; i++)
     {
       Stencil m (dash_mol);
-      m.translate_axis (span_points[LEFT] + i * dp + space_left / 2, X_AXIS);
+      m.translate_axis (span_points[LEFT] + i * dash_period + space_left / 2, X_AXIS);
       total.add_stencil (m);
     }
 
@@ -96,23 +106,28 @@ Hyphen_spanner::set_spacing_rods (SCM smob)
   r.distance_
     = robust_scm2double (me->get_property ("minimum-length"), 0);
 
-  Direction d = LEFT;
-  do
+  if (r.distance_ > 0.0)
     {
-      r.item_drul_[d] = sp->get_bound (d);
-      if (r.item_drul_[d])
-	r.distance_ += r.item_drul_[d]->extent (r.item_drul_[d], X_AXIS)[-d];
-    }
-  while (flip (&d) != LEFT);
+      Real padding = robust_scm2double (me->get_property ("padding"), 0.1);
+      r.distance_ += 2*padding;
+      Direction d = LEFT;
+      do
+	{
+	  r.item_drul_[d] = sp->get_bound (d);
+	  if (r.item_drul_[d])
+	    r.distance_ += r.item_drul_[d]->extent (r.item_drul_[d], X_AXIS)[-d];
+	}
+      while (flip (&d) != LEFT);
 
-  if (r.item_drul_[LEFT]
-      && r.item_drul_[RIGHT])
-    r.add_to_cols ();
+      if (r.item_drul_[LEFT]
+	  && r.item_drul_[RIGHT])
+	r.add_to_cols ();
+    }
 
   return SCM_UNSPECIFIED;
 }
 
 ADD_INTERFACE (Hyphen_spanner, "lyric-hyphen-interface",
 	       "A centred hyphen is a simple line between lyrics used to divide syllables",
-	       "thickness height dash-period minimum-length length");
+	       "padding thickness height dash-period minimum-length length");
 
