@@ -374,7 +374,7 @@ Spacing_spanner::set_springs (SCM smob)
     {
       global_shortest = find_shortest (me, all);
       if (be_verbose_global)
-	progress_indication (_f ("Global shortest duration is %s", global_shortest.to_string ()) + "\n");
+	message (_f ("Global shortest duration is %s", global_shortest.to_string ()) + "\n");
     }
   prune_loose_columns (me, &all, global_shortest);
   set_implicit_neighbor_columns (all);
