@@ -14,16 +14,14 @@
 	  (string-append command (if (ly:get-option 'verbose)
 				     ""
 				     " > /dev/null 2>&1 "))))
-
     (if (ly:get-option 'verbose)
-	(format (current-error-port) (_ "Invoking `~a'...") command))
+	(ly:message (_ "Invoking `~a'...") command))
     
     (set! status (system silenced))
     (if (> status 0)
 	(begin
-	  (format (current-error-port) (_ "`~a' failed (~a)") command status)
-	  (newline (current-error-port))
-	  
+	  (ly:message (_ "`~a' failed (~a)") command status)
+	  (ly:progress "\n")
 	  ;; hmmm.  what's the best failure option? 
 	  (throw 'ly-file-failed)))))
 
@@ -41,8 +39,8 @@
     (if (access? pdf-name W_OK)
 	(delete-file pdf-name))
 
-    (format (current-error-port) (_ "Converting to `~a'...") pdf-name)
-    (newline (current-error-port))
+    (ly:message (_ "Converting to `~a'...") pdf-name)
+    (ly:progress "\n")
     (ly:system cmd)))
 
 (define-public (postscript->png resolution papersizename name)
@@ -62,19 +60,17 @@
 		      name)))
     ;; Do not try to guess the name of the png file,
     ;; GS produces PNG files like BASE-page%d.png.
-    ;;(format (current-error-port) (_ "Converting to `~a'...")
+    ;;(ly:message (_ "Converting to `~a'...")
     ;;	    (string-append (basename name ".ps") "-page1.png" )))
-    (format (current-error-port) (_ "Converting to ~a...") "PNG")
-    (newline (current-error-port))
+    (ly:message (_ "Converting to ~a...") "PNG")
+    (ly:progress "\n")
     (ly:system cmd)))
 
 (define-public (postprocess-output paper-book module filename formats)
   (for-each
    (lambda (f)
-     ((eval (string->symbol (string-append "convert-to-" f))
-	    module)
+     ((eval (string->symbol (string-append "convert-to-" f)) module)
       paper-book filename))
-   
    formats))
 
 (define-public (completize-formats formats)
@@ -96,14 +92,13 @@
   (set! key (symbol->string key))
   (if (not (equal? "-" file-name))
       (set! file-name (string-append file-name "." key)))
-  (format (current-error-port)
-	  (_ "Writing header field `~a' to `~a'...")
-	  key
-	  (if (equal? "-" file-name) "<stdout>" file-name))
+  (ly:message (_ "Writing header field `~a' to `~a'...")
+	      key
+	      (if (equal? "-" file-name) "<stdout>" file-name))
   (if (equal? file-name "-")
       (display value)
       (display value (open-file file-name "w")))
-  (newline (current-error-port))
+  (ly:progress "\n")
   "")
 
 (define-public (output-scopes scopes fields basename)
