@@ -5,6 +5,7 @@
 ;;;; (c) 2000--2005  Han-Wen Nienhuys <hanwen@cs.uu.nl>
 ;;;;                  Jan Nieuwenhuizen <janneke@gnu.org>
 
+
 ;;; markup commands
 ;;;  * each markup function should have a doc string with
 ;;     syntax, description and example. 
@@ -18,10 +19,11 @@
   "Stencil as markup"
   stil)
 
-(def-markup-command (draw-circle layout props radius thickness)
-  (number? number?)
-  "A circle of radius @var{radius} and thickness @var{thickness}"
-  (make-circle-stencil radius thickness))
+(def-markup-command (draw-circle layout props radius thickness fill)
+  (number? number? boolean?)
+  "A circle of radius @var{radius}, thickness @var{thickness} and
+optionally filled."
+  (make-circle-stencil radius thickness fill))
 
 (def-markup-command (circle layout props arg) (markup?)
   "Draw a circle around @var{arg}.  Use @code{thickness},
@@ -45,16 +47,69 @@ the PDF backend."
 	 (url-expr (list 'url-link url `(quote ,xextent) `(quote ,yextent))))
     (ly:stencil-add (ly:make-stencil url-expr xextent yextent) stil)))
 
+
+(define bbox-regexp
+  (make-regexp "%%BoundingBox: ([0-9-]+) ([0-9-]+) ([0-9-]+) ([0-9-]+)"))
+
+(define (get-postscript-bbox string)
+  "Extract the bbox from STRING, or return #f if not present."
+  (let*
+      ((match (regexp-exec bbox-regexp string)))
+    
+    (if match
+	(map (lambda (x)
+	       (string->number (match:substring match x)))
+	     (cdr (iota 5)))
+	     
+	#f)))
+
+(def-markup-command (epsfile layout props file-name) (string?)
+  "Inline an EPS image. The image is scaled such that 10 PS units is
+one staff-space."
+
+  (if (ly:get-option 'safe)
+      (interpret-markup layout props "not allowed in safe") 
+      (let*
+	  ((contents (ly:gulp-file file-name))
+	   (bbox (get-postscript-bbox contents))
+	   (scaled-bbox
+	    (if bbox
+		(map (lambda (x) (/ x 10)) bbox)
+		(begin
+		  (ly:warn (_ "Could not find bounding box of `~a'")
+			   file-name)
+		  '()))))
+	
+
+	(if bbox
+	    
+	    (ly:make-stencil
+	     (list
+	      'embedded-ps
+	      (string-append
+
+	       ; adobe 5002.
+	       "BeginEPSF "
+	       "0.1 0.1 scale "
+	       (format "\n%%BeginDocument: ~a\n" file-name)
+	       contents
+	       "%%EndDocument\n"
+	       "EndEPSF\n"
+	       ))
+	     (cons (list-ref scaled-bbox 0) (list-ref scaled-bbox 2))
+	     (cons (list-ref scaled-bbox 1) (list-ref scaled-bbox 3)))
+	    
+	    (ly:make-stencil "" '(0 . 0) '(0 . 0))))))  
+
 (def-markup-command (score layout props score) (ly:score?)
   "Inline an image of music."
   (let* ((systems (ly:score-embedded-format score layout)))
 
-    (if (= 0 (vector-length systems))
+    (if (= (vector-length systems) 0)
 	(begin
-	  (ly:warn (_"No systems found in \\score markup.  Does it have a \\layout? block"))
+	  (ly:warning (_"No systems found in \\score markup.  Does it have a \\layout? block"))
 	  empty-markup)
 	(let* ((stencil (ly:paper-system-stencil (vector-ref systems 0)))) 
-	  
 	  (ly:stencil-aligned-to stencil Y CENTER)))))
 
 (def-markup-command (simple layout props str) (string?)
@@ -371,6 +426,14 @@ recommend font for this is bold and italic"
   "Draw a double flat symbol."
   (interpret-markup layout props (markup #:musicglyph "accidentals.M4")))
 
+(def-markup-command (with-color layout props color arg) (color? markup?)
+  "Draw @var{arg} in color specified by @var{color}"
+
+  (let* ((stil (interpret-markup layout props arg)))
+
+    (ly:make-stencil (list 'color color (ly:stencil-expr stil))
+		     (ly:stencil-extent stil X)
+		     (ly:stencil-extent stil Y))))
 
 ;;
 ;; TODO: should extract baseline-skip from each argument somehow..
@@ -490,6 +553,28 @@ and/or @code{extra-offset} properties. "
       (ly:stencil-translate-axis stack 0.75 Y))))
 
 
+
+(def-markup-command (filled-box layout props xext yext blot)
+  (number-pair? number-pair? number?)
+  "Draw a box with rounded corners of dimensions @var{xext} and @var{yext}."
+  (ly:round-filled-box
+   xext yext blot))
+
+(def-markup-command (whiteout layout props arg) (markup?)
+  "Provide a white underground for @var{arg}"
+  (let* ((stil (interpret-markup layout props
+				 (make-with-color-markup black arg)))
+	 (white
+	  (interpret-markup layout props
+			    (make-with-color-markup
+			     white
+			     (make-filled-box-markup
+			      (ly:stencil-extent stil X)
+			      (ly:stencil-extent stil Y)
+			      0.0)))))
+
+    (ly:stencil-add white stil)))
+
 ;; TODO: better syntax.
 
 (def-markup-command (note-by-number layout props log dot-count dir) (number? number? number?)
@@ -563,7 +648,7 @@ and/or @code{extra-offset} properties. "
                       ((string=? len "maxima") -3)
                       (else (log2 (string->number len))))
                 (if dots (string-length dots) 0)))
-        (error "This is not a valid duration string:" duration-string))))
+        (ly:error (_ "not a valid duration string: ~a") duration-string))))
 
 (def-markup-command (note layout props duration dir) (string? number?)
   "This produces a note with a stem pointing in @var{dir} direction, with
