@@ -18,22 +18,20 @@
 
 (define framework-ps-module (current-module))
 
-(define (stderr string . rest)
-  (apply format (cons (current-error-port) (cons string rest)))
-  (force-output (current-error-port)))
-
 ;;(define pdebug stderr)
 (define (pdebug . rest) #f)
 
 (define mm-to-bigpoint
   (/ 72 25.4))
 
-(define-public (ps-font-command font . override-coding)
-  (let* ((name (ly:font-file-name font))
+
+(define-public (ps-font-command font)
+  (let* ((name (munge-lily-font-name (ly:font-file-name font)))
 	 (magnify (ly:font-magnification font)))
 
     (string-append
-     "magfont" (string-encode-integer (hashq  name 1000000))
+     "magfont"
+     (string-regexp-substitute "[ /%]" "_" name)
      "m" (string-encode-integer (inexact->exact (round (* 1000 magnify)))))))
 
 (define (tex-font? fontname)
@@ -41,14 +39,6 @@
    (equal? (substring fontname 0 2) "cm")
    (equal? (substring fontname 0 2) "ec")))
 
-(define (ps-embed-pfa body font-name version)
-  (string-append
-   (format
-    "%%BeginResource: font ~a
-~a
-%%EndResource\n"
-    font-name body)))
-
 
 (define (define-fonts paper)
   (define font-list (ly:paper-fonts paper))
@@ -64,12 +54,12 @@
   (define (font-load-command font)
     (let* ((specced-font-name (ly:font-name font))
 	   (fontname (if specced-font-name
-			 specced-font-name
+			 (munge-lily-font-name specced-font-name)
 			 (ly:font-file-name font)))
 	   (command (ps-font-command font))
 
 	   ;; FIXME -- see (ps-font-command )
-	   (plain (ps-font-command font #f))
+	   (plain (ps-font-command font))
 	   (designsize (ly:font-design-size font))
 	   (magnification (* (ly:font-magnification font)))
 	   (ops (ly:output-def-lookup paper 'outputscale))
@@ -120,35 +110,32 @@
    (output-entry "page-width" 'hsize)))
 
 (define (dump-page outputter page page-number page-count landscape?)
-  (ly:outputter-dump-string outputter
-			    (string-append
-			     "%%Page: "
-			     (number->string page-number) " " (number->string page-count) "\n"
-
-			     "%%BeginPageSetup\n"
-			     (if landscape?
-				 "page-width output-scale
- lily-output-units mul
- mul 0 translate 90 rotate\n"
-				 "")
-			     "%%EndPageSetup\n"
-
-			     "start-page { "
-			     "set-ps-scale-to-lily-scale "
-			     "\n"))
+  (ly:outputter-dump-string
+   outputter
+   (string-append
+    "%%Page: "
+    (number->string page-number) " " (number->string page-count) "\n"
+    
+    "%%BeginPageSetup\n"
+    (if landscape?
+	"page-width output-scale lily-output-units mul mul 0 translate 90 rotate\n"
+	"")
+    "%%EndPageSetup\n"
+    
+    "start-page { "
+    "set-ps-scale-to-lily-scale "
+    "\n"))
   (ly:outputter-dump-stencil outputter page)
   (ly:outputter-dump-string outputter "} stop-system \nshowpage\n"))
 
-
 (define (supplies-or-needs paper load-fonts?)
   (define (extract-names font)
     (if (ly:pango-font? font)
 	(map car (ly:pango-font-physical-fonts font))
-	(list (ly:font-name font))))
+	(list (munge-lily-font-name (ly:font-name font)))))
   
   (let* ((fonts (ly:paper-fonts paper))
-	 (names (apply append (map extract-names fonts)))
-	 )
+	 (names (apply append (map extract-names fonts))))
     
     (apply string-append
 	   (map (lambda (f)
@@ -160,7 +147,7 @@
 		(uniq-list (sort names string<?))))))
 
 (define (eps-header paper bbox load-fonts?)
-    (string-append "%!PS-Adobe-2.0 EPSF-2.0\n"
+  (string-append "%!PS-Adobe-2.0 EPSF-2.0\n"
 		 "%%Creator: LilyPond\n"
 		 "%%BoundingBox: "
 		 (string-join (map ly:number->string bbox) " ") "\n"
@@ -200,64 +187,95 @@
    "%%BeginSetup\n"
    (define-fonts paper)
    (output-variables paper)
-   "init-lilypond-parameters\n"
    "%%EndSetup\n"))
 
+(define-public (munge-lily-font-name name)
+  (regexp-substitute/global #f "([eE]mmentaler|[aA]ybabtu)"
+			    name 'pre "PFA" 1 'post))
+
 (define (write-preamble paper load-fonts? port)
+  (define (load-font font-pair)
+    (let* ((name (car font-pair))
+	   (file-name (cdr font-pair))
+		 
+	   (bare-file-name (ly:find-file file-name))
+	   (cffname (string-append file-name ".cff.ps"))
+	   (cff-file-name (ly:find-file cffname)))
+
+      (cons 
+       (munge-lily-font-name name)
+       (cond
+	((and bare-file-name (string-match "\\.pfa" bare-file-name))
+	 (cached-file-contents bare-file-name))
+	((and bare-file-name (string-match "\\.pfb" bare-file-name))
+	 (ly:pfb->pfa bare-file-name))
+	
+	((string-match "([eE]mmentaler|[Aa]ybabtu)" file-name)
+	 (cached-file-contents
+	  (format "~a.pfa" (munge-lily-font-name file-name))))
+
+	((and bare-file-name
+	      (string-match "\\.(otf|cff)" bare-file-name))
+
+					; replace with the CFF.ps, which lives in a
+					; separate subdir.
+	 (for-each (lambda (tup)
+		     (set! bare-file-name
+			   (string-regexp-substitute
+			    (car tup) (cdr tup) bare-file-name)))
+		   '(("/fonts/otf/" . "/ps/")
+		     ("/fonts/cff/" . "/ps/")
+		     ("\\.(otf|cff)" . ".cff.ps")))
+
+	 (cached-file-contents bare-file-name))
+	((and bare-file-name (string-match "\\.ttf" bare-file-name))
+	 (ly:ttf->pfa bare-file-name))
+	(bare-file-name (cached-file-contents bare-file-name))
+	(cff-file-name  (cached-file-contents cff-file-name))
+	(else
+	 (ly:warning (_ "can't find CFF/PFA/PFB font ~S=~S" name file-name))
+	 (cons font-name ""))))))
+  
   (define (load-fonts paper)
     (let* ((fonts (ly:paper-fonts paper))
+
 	   (all-font-names
 	    (map
 	     (lambda (font)
 	       (cond
-		((string? (ly:font-file-name font)) (list (ly:font-file-name font)))
+		((string? (ly:font-file-name font))
+		 (list (cons (ly:font-name font)
+			     (ly:font-file-name font))))
 		((ly:pango-font? font)
-		 (map cdr  (ly:pango-font-physical-fonts font)))
-		(else (ly:font-sub-fonts font))))
+		 (ly:pango-font-physical-fonts font))
+		(else
+		 (ly:font-sub-fonts font))))
 		   
 	     fonts))
-	   
 	   (font-names
 	    (uniq-list
-	     (sort (apply append all-font-names) string<?)))
-	   (pfas (map
-		  (lambda (x)
-		    (let* ((bare-file-name (ly:find-file x))
-			   (cffname (string-append x ".cff.ps"))
-			   (cff-file-name (ly:find-file cffname))
-			   )
-		      (cond
-		       ((and bare-file-name (string-match "\\.pfa" bare-file-name))
-			(cached-file-contents bare-file-name))
-		       ((and bare-file-name (string-match "\\.pfb" bare-file-name))
-			(ly:pfb->pfa bare-file-name))
-		       ((and bare-file-name
-			     (string-match "\\.(otf|cff)" bare-file-name))
+	     (sort (apply append all-font-names)
+		   (lambda (x y) (string<? (car x) (car y))))))
+	   
+	   (pfas (map load-font font-names)))
+      pfas))
 
-			; replace with the CFF.ps, which lives in a
-			; separate subdir.
-			(for-each (lambda (tup)  (set! bare-file-name
-						       (string-regexp-substitute (car tup) (cdr tup) bare-file-name)))
-				  '(("/fonts/otf/" . "/ps/")
-				    ("/fonts/cff/" . "/ps/")
-				    ("\\.(otf|cff)" . ".cff.ps")))
-
-			(cached-file-contents bare-file-name))
-		       ((and bare-file-name (string-match "\\.ttf" bare-file-name))
-			(ly:ttf->pfa bare-file-name))
-		       (bare-file-name (cached-file-contents bare-file-name))
-		       (cff-file-name  (cached-file-contents cff-file-name))
-		       (else
-			(ly:warn "cannot find CFF/PFA/PFB font ~S" x)
-			""))))
-		  (filter string? font-names))))
-	   pfas))
+  (if load-fonts?
+      (for-each
+       (lambda (f)
+	 (format port "\n%%BeginFont: ~a\n" (car f))
+	 (display (cdr f) port)
+	 (display "\n%%EndFont\n" port))
+       (load-fonts paper)))
+      
+  (display (setup paper) port)
 
+  ; adobe note 5002: should initialize variables before loading routines.
   (display (procset "music-drawing-routines.ps") port)
   (display (procset "lilyponddefs.ps") port)
-  (if load-fonts?
-      (for-each (lambda (f) (display f port)) (load-fonts paper)))
-  (display (setup paper) port))
+  (display "init-lilypond-parameters\n" port)
+
+  )
 
 (define-public (output-framework basename book scopes fields)
   (let* ((filename (format "~a.ps" basename))
@@ -282,55 +300,47 @@
     (display "%%Trailer\n%%EOF\n" port)
     (ly:outputter-close outputter)
     (postprocess-output book framework-ps-module filename
-			 (completize-formats (ly:output-formats)))
-))
+			 (completize-formats (ly:output-formats)))))
 
 (if (not (defined? 'nan?))
     (define (nan? x) #f))
+
 (if (not (defined? 'inf?))
     (define (inf? x) #f))
 
-
 (define-public (dump-stencil-as-EPS paper dump-me filename load-fonts?)
   (define (mm-to-bp-box mmbox)
-    (let*
-	((scale  (ly:output-def-lookup paper 'outputscale))
-	 (box (map 
-	       (lambda (x)
-		 (inexact->exact
-		  (round (* x scale mm-to-bigpoint)))) mmbox)))
+    (let* ((scale  (ly:output-def-lookup paper 'outputscale))
+	   (box (map 
+		 (lambda (x)
+		   (inexact->exact
+		    (round (* x scale mm-to-bigpoint)))) mmbox)))
 
     (list (car box) (cadr box)
 	  (max (1+ (car box)) (caddr box))
 	  (max (1+ (cadr box)) (cadddr box)))))
-  
-  (let*
-      ((outputter (ly:make-paper-outputter (format "~a.eps" filename)
-					   "ps"))
-       
-       (port (ly:outputter-port outputter))
-       (xext (ly:stencil-extent dump-me X))
-       (yext (ly:stencil-extent dump-me Y))
-       
-       (bbox
-	(map
-	 (lambda (x)
-	   (if (or (nan? x) (inf? x))
-	       0.0 x))
-	 (list (car xext) (car yext)
+
+  (let* ((outputter (ly:make-paper-outputter (format "~a.eps" filename) "ps"))
+	 (port (ly:outputter-port outputter))
+	 (xext (ly:stencil-extent dump-me X))
+	 (yext (ly:stencil-extent dump-me Y))
+	 (bbox
+	  (map
+	   (lambda (x)
+	     (if (or (nan? x) (inf? x))
+		 0.0 x))
+	   (list (car xext) (car yext)
 	       (cdr xext) (cdr yext))))
-       (rounded-bbox (mm-to-bp-box bbox))
-       (port (ly:outputter-port outputter))
-       (header (eps-header paper rounded-bbox load-fonts?)))
+	 (rounded-bbox (mm-to-bp-box bbox))
+	 (port (ly:outputter-port outputter))
+	 (header (eps-header paper rounded-bbox load-fonts?)))
 
     (display header port)
     (write-preamble paper load-fonts? port)
     (display "start-system { set-ps-scale-to-lily-scale \n" port)
     (ly:outputter-dump-stencil outputter dump-me)
     (display "} stop-system\n%%Trailer\n%%EOF\n" port)
-    (ly:outputter-close outputter)
-    ))
-
+    (ly:outputter-close outputter)))
 
 (define-public (output-preview-framework basename book scopes fields)
   (let* ((paper (ly:paper-book-paper book))
@@ -348,16 +358,14 @@
 			 (format "~a.preview" basename)
 			 #t)))
 
-
-
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (define-public (convert-to-pdf book name)
   (let* ((defs (ly:paper-book-paper book))
 	 (papersizename (ly:output-def-lookup defs 'papersizename)))
 
-    (if (equal? name "-")
-	(ly:warn "Can't convert <stdout> to PDF")
+    (if (equal? (basename name ".ps") "-")
+	(ly:warning (_ "can't convert <stdout> to ~S" "PDF"))
 	(postscript->pdf (if (string? papersizename) papersizename "a4")
 			 name))))
 
@@ -372,10 +380,10 @@
 		     name)))
 
 (define-public (convert-to-dvi book name)
-  (ly:warn "Can not generate DVI via the postscript back-end"))
+  (ly:warning (_ "can't generate ~S using the postscript back-end") "DVI"))
 
 (define-public (convert-to-tex book name)
-  (ly:warn "Can not generate TeX via the postscript back-end"))
+  (ly:warning (_ "can't generate ~S using the postscript back-end") "TeX"))
 
 (define-public (convert-to-ps book name)
   #t)
