@@ -102,11 +102,6 @@ lilypond -fgnome input/simple-song.ly
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; helper functions
 
-(define (stderr string . rest)
-  (apply format (cons (current-error-port) (cons string rest)))
-  (force-output (current-error-port)))
-
-
 (define (utf8 i)
   (cond
    ((< i #x80) (list (integer->char i)))
