@@ -111,8 +111,9 @@
 	 (defs (ly:output-def-lookup layout 'text-font-defaults))
 	 (props (ly:grob-alist-chain grob defs))
 	 (circle (Text_interface::interpret_markup
-		  layout props (make-draw-circle-markup 0.8 0.1)))
+		  layout props (make-draw-circle-markup 0.8 0.1 #f)))
 	 (text-stencil (Text_interface::interpret_markup layout props text)))
+    
     (ly:stencil-add (centered-stencil text-stencil) circle)))
 
 
@@ -242,7 +243,7 @@ centered, X==1 is at the right, X == -1 is at the left."
 			 ("bracket" . (() . "bracket"))  ))))
 
     (if (equal? result #f)
-	(ly:warn "Unknown bar glyph: `~S'" glyph)
+	(ly:warning (_ "unknown bar glyph: `~S'" glyph))
 	(index-cell (cdr result) dir))))
 
 (define-public (shift-right-at-line-begin g)
