@@ -107,9 +107,13 @@
     (list arch_angle arch_width arch_height height arch_thick thick))
    " draw_bracket"))
 
-(define (circle radius thick)
+(define (circle radius thick fill)
   (format
-   "~a ~a draw_circle" radius thick))
+   "~a ~a ~a draw_circle" radius thick
+   (if fill
+       "true "
+       "false ")
+   ))
 
 (define (char font i)
   (string-append 
@@ -186,8 +190,8 @@
 
 	    (if (and (= 0.0 x)
 		     (= 0.0 y))
-		(format #f " /~a glyphshow " g)
-		(format #f " ~a ~a rmoveto /~a glyphshow "
+		(format #f " /~a glyphshow\n" g)
+		(format #f " ~a ~a rmoveto /~a glyphshow\n"
 			x y g))))
 	x-y-named-glyphs))
   ))
@@ -272,7 +276,8 @@
   " setrgbcolor\n"))
 
 (define (text font s)
-;  (ly:warn "TEXT backend-command encountered in Pango backend\nargs: ~a ~a" font str)
+  ;; (ly:warning (_ "TEXT backend-command encountered in Pango backend"))
+  ;; (ly:warning (_ "Arguments: ~a ~a"" font str))
   
   (let* ((space-length (cdar (ly:text-dimension font " ")))
 	 (space-move (string-append (number->string space-length)
@@ -303,7 +308,7 @@
 	  url))
 
 (define (utf8-string pango-font-description string)
-  (ly:warn "utf8-string encountered in PS backend"))
+  (ly:warning (_ "utf8-string encountered in PS backend")))
 
 (define (white-dot x y radius)
   (string-append
