@@ -58,11 +58,11 @@ version taken from the \\version command, to the current LilyPond version."""))
 	sys.stdout.write ('\n')
 	sys.stdout.write (_ ("""\
   -e, --edit             edit in place
-  -f, --from=VERSION     start from version [default: \\version found in file]
+  -f, --from=VERSION     start from VERSION [default: \\version found in file]
   -h, --help             print this help
   -n, --no-version       do not add \\version command if missing
   -s, --show-rules       print rules [default: --from=0, --to=@TOPLEVEL_VERSION@]
-  -t, --to=VERSION       convert to version [default: @TOPLEVEL_VERSION@]
+  -t, --to=VERSION       convert to VERSION [default: @TOPLEVEL_VERSION@]
   -v, --version          print program version"""))
 	sys.stdout.write ('\n\n')
 	sys.stdout.write (_ ("Report bugs to %s.") % "bug-lilypond@gnu.org")
@@ -2354,12 +2354,17 @@ conversions.append (((2, 5, 1),
 		     'ly:import-module -> ly:module-copy'))
 
 def conv (str):
-	str = re.sub (r'\\(column|fill-line|dir-column|center-align|right-align|left-align|bracketed-y-column)\s*<([^<]*)>',
+	str = re.sub (r'\\(column|fill-line|dir-column|center-align|right-align|left-align|bracketed-y-column)\s*<(([^>]|<[^>]*>)*)>',
 		      r'\\\1 {\2}', str)
-	str = re.sub (r'\\(column|fill-line|dir-column|center-align|right-align|left-align|bracketed-y-column)\s*<([^<]*)>',
+	str = re.sub (r'\\(column|fill-line|dir-column|center-align|right-align|left-align|bracketed-y-column)\s*<(([^>]|<[^>]*>)*)>',
 		      r'\\\1 {\2}', str)
-	str = re.sub (r'\\(column|fill-line|dir-column|center-align|right-align|left-align|bracketed-y-column)\s*<([^<]*)>',
+	str = re.sub (r'\\(column|fill-line|dir-column|center-align|right-align|left-align|bracketed-y-column)\s*<(([^>]|<[^>]*>)*)>',
 		      r'\\\1 {\2}', str)
+	def get_markup (m):
+		s = m.group (0)
+		s = re.sub (r'''((\\"|})\s*){''', '\2 \\line {', s)
+		return s
+	str = re.sub (r'\\markup\s*{([^}]|{[^}]*})*}', get_markup, str)
 	return str
 
 conversions.append (((2, 5, 2),
@@ -2462,7 +2467,14 @@ conversions.append (((2, 5, 17),
 		     conv,
 		     'ly:stencil-set-extent! removed'))
 		    
+def conv (str):
+	str = re.sub (r"ly:warn\b", 'ly:warning', str)
+	return str
 
+conversions.append (((2, 5, 18),
+		     conv,
+		     'ly:warn -> ly:warning'))
+		    
 ################################
 #	END OF CONVERSIONS
 ################################
@@ -2617,7 +2629,7 @@ for f in files:
 		do_one_file (f)
 	except UnknownVersion:
 		sys.stderr.write ('\n')
-		sys.stderr.write (_ ("%s: cannot determine version for `%s'") \
+		sys.stderr.write (_ ("%s: can't determine version for `%s'") \
 				  % (program_name, f))
 		sys.stderr.write ('\n')
 		if assume_old:
